============
Installation
============

Developer instructions listed at https://github.com/ethz-randomwalk/polytopewalk

Or, if you have pip installed:

.. code-block:: bash

    pip install polytopewalk